==> moodle-1.5-pgsql.tgz: moodle/lang/tl/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 ALPHA (2005043000)


$string['addanewdiscussion'] = 'Magdagdag ng bagong paksang pag-uusapan';
$string['addanewtopic'] = 'Magdagdag ng bagong paksa';
$string['advancedsearch'] = 'Abanteng paghahanap';
$string['allforums'] = 'Lahat ng talakayan';
$string['allowchoice'] = 'Pahintulutan ang lahat na makapamil';
$string['allowdiscussions'] = 'Maaari bang magpost ang $a sa talakayang ito?';
$string['allowratings'] = 'Pahihintulutan bang malagyan ng rating ang mga post?';
$string['allowsdiscussions'] = 'Pinapahintulutan ng talakayang ito ang bawat tao na magsimula ng isang paksa na pag-uusapan.';
$string['anyfile'] = 'Anumang file';
$string['attachment'] = 'Kalakip';
$string['bynameondate'] = 'ni $a->name - $a->date';
$string['configcleanreadtime'] = 'Oras sa isang araw para malinis ang mga lumang post mula sa \'read\' na teybol.';
$string['configdisplaymode'] = 'Ang default na mode ng displey para sa pinag-uusapan kung walang itinakda.';
$string['configenablerssfeeds'] = 'Bubuhayin ng swits na ito ang posibilidad ng RSS feed para sa lahat ng talakayan.  Kakailanganin mo pa ring buhayin ang feed ng mano-mano sa mga kaayusan ng bawat talakayan.';
$string['configlongpost'] = 'Ang anumang post na lampas sa habang ito (dikasama ang HTML) ay itinuturing na mahaba.';
$string['configmanydiscussions'] = 'Maksimum na bilang ng pinag-uusapan na ipapakita sa isang talakayan bawat pahina';
$string['configmaxbytes'] = 'Default na maksimum na laki para sa lahat ng kalakip sa talakayan sa site (alinsunod sa limitasyon sa kurso at iba pang lokal na kaayusan)';
$string['configoldpostdays'] = 'Bilang ng araw na lumipas para ituring na nabasa na ang alinmang post';
$string['configreplytouser'] = 'Kapag ang post sa talakayan ay ipinahatid balita, dapat ba itong maglaman ng email address ng email upang makatugon ang tatanggap ng personal sa halip na sa pamamagitan ng talakayan?  Kahit itakda na \'Oo\', maaari pa ring ilihim ng user ang email address nila sa pamamagitan ng kanilang pagkakakilanlan.';
$string['configshortpost'] = 'Anumang post na kulang sa haba na ito (dikasama ang HTML) ay itinuturing na maigsi.';
$string['configtrackreadposts'] = 'Itakda sa \'Oo\' kung nais mong i-track and nabasa/dinabasa para sa bawat user';
$string['configusermarksread'] = 'Kung \'oo\', kailang markahan ng user ang post ng \'nabasa\' nang mano-mano.  Kung \'hindi\', kapag ang post ay tiningnan ito ay mamarkahan na ng \'nabasa\'.';
$string['couldnotadd'] = 'Hindi maidagdag ang post mo dahil sa dimalamang error';
$string['couldnotdeleteratings'] = 'Paumanhin, hindi iyan maaaring mabura dahil nalagyan na ng rating ng mga tao.';
$string['couldnotdeletereplies'] = 'Paumanhin, hindi iyan maaaring mabura dahil tumugon na ang mga tao diyan.';
$string['couldnotupdate'] = 'Hindi mabago ang post mo dahil sa dimalamang dahilan';
$string['delete'] = 'Burahin';
$string['deleteddiscussion'] = 'Ang paksang pinag-uusapan ay binura na';
$string['deletedpost'] = 'Ang post ay binura na';
$string['deletedposts'] = 'Binura ang mga post na iyon';
$string['deletesure'] = 'Talaga bang nais mong burahin ang post na ito?';
$string['deletesureplural'] = 'Talaga bang nais mong burahin ang post na ito at lahat ng tugon dito? ($a post)';
$string['digestmailheader'] = 'Ito ang arawan mong digest ng bagong post mula sa $a->sitename na talakayan.  Para mabago ang mas-ibig mong kaayusan sa pantalakayang email, pumunta sa $a->userprefs.';
$string['digestmailprefs'] = 'ang pagkakakilanlan mo';
$string['digestmailsubject'] = '$a: digest ng talakayan';
$string['digestsentusers'] = 'Matagumpay na naihatid ang email digest sa $a user.';
$string['discussion'] = 'Pinag-uusapan';
$string['discussionmoved'] = 'Ang pinag-uusapan na ito ay inilipat sa \'$a\'.';
$string['discussionname'] = 'Pangalan ng pinag-uusapan';
$string['discussions'] = 'Mga Pinag-uusapan';
$string['discussionsstartedby'] = 'Mga pinag-uusapan na sinimulan ni $a';
$string['discussionsstartedbyrecent'] = 'Pinakabagong pinag-uusapan na sinimulan ni $a';
$string['discussthistopic'] = 'Pag-usapan ang paksang ito';
$string['eachuserforum'] = 'Ang bawat tao ay nagpopost ng isang pag-uusapan';
$string['edit'] = 'Iedit';
$string['editedby'] = 'Inedit ni $a->name - $a->date';
$string['editing'] = 'Nageedit';
$string['emptymessage'] = 'May problema ang post mo.  Marahil ay blangko ito, o ang kalakip ay masyadong malaki.  Ang mga pagbabago mo ay HINDI nasave.';
$string['everyonecanchoose'] = 'Lahat ay maaaring sumali';
$string['everyoneissubscribed'] = 'Lahat ay kasali sa talakayang ito';
$string['existingsubscribers'] = 'Mga kasalukuyang kasali';
$string['forcesubscribe'] = 'Pilitin ang lahat na sumali';
$string['forcesubscribeq'] = 'Pipilitin ba ang lahat na sumali?';
$string['forum'] = 'Talakayan';
$string['forumintro'] = 'Panimula ng talakayan';
$string['forumname'] = 'Pangalan ng talakayan';
$string['forumposts'] = 'Mga post sa talakayan';
$string['forums'] = 'Mga talakayan';
$string['forumtype'] = 'Uri ng talakayan';
$string['generalforum'] = 'Karaniwang talakayan para sa pangkalahatang gamit';
$string['generalforums'] = 'Mga pangkalahatang talakayan';
$string['inforum'] = 'sa $a';
$string['intronews'] = 'Mga pangkalahatang balita at anunsiyo';
$string['introsocial'] = 'Bukas na talakayan para sa pakikipaghuntahan tungkol sa anumang bagay na nais mong pag-usapan.';
$string['introteacher'] = 'Talakayan para sa pangguro-lamang na mga tal at pag-uusapan';
$string['lastpost'] = 'Huling post';
$string['learningforums'] = 'Mga talakayan para sa pag-aaral';
$string['markalldread'] = 'Markahan ang lahat ng post sa pag-uusap na ito na \"nabasa na\".';
$string['markallread'] = 'Markahan ang lahat ng post sa talakayang ito na \"nabasa na\".';
$string['markread'] = 'Markahan na \"nabasa na\"';
$string['markreadbutton'] = 'Markahan na<br />nabasa na';
$string['markunread'] = 'Markahan na dinabasa';
$string['markunreadbutton'] = 'Markahan na<br />dinabasa';
$string['maxattachmentsize'] = 'Maksimum na laki ng kalakip';
$string['maxtimehaspassed'] = 'Paumanhin, nguni\'t ang taning na oras para maedit ang post na ito ($a) ay lumipas na!';
$string['message'] = 'Mensahe';
$string['missingsearchterms'] = 'Ang mga sumusunod na hinahanap na termino ay nasa HTML markup lamang ng mensaheng ito:';
$string['modeflatnewestfirst'] = 'Ipakita ang mga tugon nang flat, una ang pinakabago';
$string['modeflatoldestfirst'] = 'Ipakita ang mga tugon nang flat, una ang pinakaluma';
$string['modenested'] = 'Ipakita ang mga tugon sa anyong nakanest';
$string['modethreaded'] = 'Ipakita ang mga tugon sa anyong nakathread';
$string['modulename'] = 'Talakayan';
$string['modulenameplural'] = 'Mga Talakayan';
$string['more'] = 'marami pa';
$string['movethisdiscussionto'] = 'Ilipat ang pinag-uusapang ito sa ... ';
$string['namenews'] = 'Balitaan';
$string['namesocial'] = 'Tambayan';
$string['nameteacher'] = 'Talakayan ng guro';
$string['newforumposts'] = 'Mga bagong post sa talakayan';
$string['nodiscussions'] = 'Wala pang pag-uusapang paksa sa talakayang ito';
$string['noguestpost'] = 'Paumanhin, pero hindi pinapahintulutang magpost ang mga bisita';
$string['noguestsubscribe'] = 'Paumanhin, nguni\'t ang mga bisita ay hindi pinapahintulutang sumali upang makatanggap ng post sa talakayan sa pamamagitan ng email.';
$string['noguesttracking'] = 'Paumanhin, nguni\'t hindi pinapahintulutan ang bisita na magtakda ng mga opsiyon sa pagsubaybay.';
$string['nomorepostscontaining'] = 'Wala nang matagpuang post na naglalaman ng \'$a\' ';
$string['nonews'] = 'Wala pang balita na ipinopost';
$string['noposts'] = 'Walang post';
$string['nopostscontaining'] = 'Walang natagpuang post na naglalaman ng \'$a\' ';
$string['nosubscribers'] = 'Wala pang kasali sa talakayang ito';
$string['notingroup'] = 'Paumanhin, nguni\'t kailangan ay kabilang ka sa isang pangkat para makita ang talakayang ito.';
$string['notrackforum'] = 'Huwag subaybayan ang mga dipanabasang mensahe';
$string['nownotsubscribed'] = 'Si $a->name ay HINDI makakatanggap ng kopya ng \'$a->forum\' sa pamamagitan ng email.';
$string['nownottracking'] = 'Si $a->name ay hindi na sinusubaybayan ang \'$a->forum\'.';
$string['nowsubscribed'] = 'Si $a->name ay makakatanggap ng kopya ng \'$a->forum\' sa pamamagitan ng email.';
$string['nowtracking'] = 'Sinusubaybayan na ni $a->name ang \'$a->forum\'.';
$string['numposts'] = '$a post';
$string['olderdiscussions'] = 'Mas luma na pinag-uusapan';
$string['oldertopics'] = 'Mas lumang paksa';
$string['openmode0'] = 'Walang pinag-uusapan, walang tugon';
$string['openmode1'] = 'Walang pinag-uusapan, nguni\'t pinapahintulutan ang pagtugon';
$string['openmode2'] = 'Pinapahintulutan ang mga pag-uusap at pagtugon';
$string['parent'] = 'Ipakita ang pinagsimulan';
$string['parentofthispost'] = 'Pinagsimulan ng post na ito';
$string['postadded'] = 'Matagumpay na naidagdag ang post mo.<p>May $a ka para maedit ito kung gusto mong baguhin.</p>';
$string['postincontext'] = 'Tingnan ang post na ito nang nasa konteksto';
$string['postmailinfo'] = 'Ito ay kopya ng mensaheng ipinost sa $a na website.

Upang maidagdag ang tugon mo sa pamamagitan ng website, iklik ang link na ito:';
$string['postrating1'] = 'Karamihan ay Hiwalay na Pag-alam';
$string['postrating2'] = 'Hiwalay at Konektado';
$string['postrating3'] = 'Karamihan ay Konektadong Pag-alam';
$string['posts'] = 'Mga Post';
$string['posttoforum'] = 'Magpost sa talakayan';
$string['postupdated'] = 'Nabago na ang post mo';
$string['potentialsubscribers'] = 'Mga posibleng kasali';
$string['processingdigest'] = 'Pinoproseso ang email digest para sa user na $a';
$string['processingpost'] = 'Pinoproseso ang post na $a';
$string['prune'] = 'Hatiin';
$string['prunedpost'] = 'A new discussion has been created from that post';
$string['pruneheading'] = 'Hatiin ang pinag-uusapan at ilipat ang post na ito sa bagong pag-uusapan';
$string['rate'] = 'Rate';
$string['rating'] = 'Rating';
$string['ratingeveryone'] = 'Lahat ay maaaring magbigay ng rate sa mga post';
$string['ratingno'] = 'Walang rating';
$string['ratingonlyteachers'] = 'Tanging ang $a ang makapagbibigay ng rate sa mga post';
$string['ratingpublic'] = 'Ang $a ay maaaring makita ang rating ng lahat';
$string['ratingpublicnot'] = 'Ang $a ay maaari lamang makita ang sarili nilang rating';
$string['ratings'] = 'Mga Rating';
$string['ratingssaved'] = 'Nasave na ang mga rating';
$string['ratingsuse'] = 'Gumamit ng rating';
$string['ratingtime'] = 'Ibigay lamang ang rating sa mga post na may petsa na nasa agwat na ito:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Basahin ang nalalabing bahagi ng paksang ito';
$string['replies'] = 'Mga tugon';
$string['repliesmany'] = '$a tugon sa kasalukuyan';
$string['repliesone'] = '$a tugon sa kasalukuyan';
$string['reply'] = 'Tumugon';
$string['replyforum'] = 'Tumugon sa talakayan';
$string['rsssubscriberssdiscussions'] = 'Ipakita ang RSS eed para sa  \'$a\' na pinag-uusapan';
$string['rsssubscriberssposts'] = 'Ipakita ang RSS feed para sa \'$a\' na post';
$string['search'] = 'Hanapin';
$string['searchdatefrom'] = 'Dapat ay mas bago ang mga post kaysa dito';
$string['searchdateto'] = 'Dapat ay mas luma ang mga post kaysa dito';
$string['searchforumintro'] = 'Pakipasok ang mga terminong hahanapin sa isa o mahigit pa sa mga sumusunod an field:';
$string['searchforums'] = 'Hanapin sa mga talakayan';
$string['searchfullwords'] = 'Dapat lumitaw ang mga salitang ito na buong salita';
$string['searchnotwords'] = 'HINDI dapat isama ang mga salitang ito';
$string['searcholderposts'] = 'Hanapin sa mga lumang post...';
$string['searchphrase'] = 'Kailangang lumitaw ang eksaktong kataga na ito sa post';
$string['searchresults'] = 'Resulta ng paghahanap';
$string['searchsubject'] = 'Dapat ay nasa paksa ang mga salitang ito';
$string['searchuser'] = 'Dapat tumugma ang pangalan sa awtor';
$string['searchuserid'] = 'Ang Moodle ID ng awtor';
$string['searchwhichforums'] = 'Piliin kung aling talakayan ang hahanapan';
$string['searchwords'] = 'Maaaring lumitaw ang mga salitang ito saanman sa post';
$string['seeallposts'] = 'Tingnan ang lahat ng post na ginawa ng user na ito';
$string['sendinratings'] = 'Ipadala ang pinakabago kong rating';
$string['showsubscribers'] = 'Ipakita/editin ang mga kasalukuyang kasali';
$string['singleforum'] = 'Isang payak na pag-uusapan';
$string['startedby'] = 'Sinimulan ni';
$string['subject'] = 'Paksa';
$string['subscribe'] = 'Sumali sa talakayang ito';
$string['subscribeall'] = 'Isali ang lahat sa talakayang ito';
$string['subscribed'] = 'Kasali na';
$string['subscribenone'] = 'Tanggalin ang lahat sa talakayang ito';
$string['subscribers'] = 'Mga kasali';
$string['subscribersto'] = 'Mga kasali sa \'$a\'';
$string['subscribestart'] = 'Padalhan mo ako ng email na kopya ng mga post sa talakayang ito';
$string['subscribestop'] = 'Huwag mo akong padalhan ng email na kopya ng mga post sa talakayang ito';
$string['subscription'] = 'Sinalihan';
$string['subscriptions'] = 'Mga sinalihan';
$string['trackforum'] = 'Subaybayan ang mga dipanabasang mensahe';
$string['tracking'] = 'Subaybayan';
$string['trackingoff'] = 'Patay';
$string['trackingon'] = 'Buhay';
$string['trackingoptional'] = 'Opsiyonal';
$string['trackingtype'] = 'Babasahin ba ang pagsubaybay sa talakayang ito?';
$string['unread'] = 'Dinabasa';
$string['unreadposts'] = 'Mga dinabasang post';
$string['unreadpostsnumber'] = '$a dinabasang post';
$string['unreadpostsone'] = '1 dinabasang post';
$string['unsubscribe'] = 'Tanggalin sa talakayang ito';
$string['unsubscribed'] = 'Tinanggal';
$string['unsubscribeshort'] = 'Tanggalin';
$string['yesforever'] = 'Oo, magpakailanman';
$string['yesinitially'] = 'Oo, sa simula';
$string['youratedthis'] = 'Binigyan mo ng rate ito';
$string['yournewtopic'] = 'Ang bago mong paksang pinag-uusapan';
$string['yourreply'] = 'Ang iyong tugon';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/tl/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.6 development (2005060201)


$string['addanewdiscussion'] = 'Magdagdag ng bagong paksang pag-uusapan';
$string['addanewtopic'] = 'Magdagdag ng bagong paksa';
$string['advancedsearch'] = 'Abanteng paghahanap';
$string['allforums'] = 'Lahat ng talakayan';
$string['allowchoice'] = 'Pahintulutan ang lahat na makapamil';
$string['allowdiscussions'] = 'Maaari bang magpost ang $a sa talakayang ito?';
$string['allowratings'] = 'Pahihintulutan bang malagyan ng rating ang mga post?';
$string['allowsdiscussions'] = 'Pinapahintulutan ng talakayang ito ang bawat tao na magsimula ng isang paksa na pag-uusapan.';
$string['anyfile'] = 'Anumang file';
$string['attachment'] = 'Kalakip';
$string['bynameondate'] = 'ni $a->name - $a->date';
$string['configcleanreadtime'] = 'Oras sa isang araw para malinis ang mga lumang post mula sa \'read\' na teybol.';
$string['configdisplaymode'] = 'Ang default na mode ng displey para sa usapan kung walang itinakda.';
$string['configenablerssfeeds'] = 'Bubuhayin ng swits na ito ang posibilidad ng RSS feed para sa lahat ng talakayan.  Kakailanganin mo pa ring buhayin ang feed ng mano-mano sa mga kaayusan ng bawat talakayan.';
$string['configlongpost'] = 'Ang anumang post na lampas sa habang ito (dikasama ang HTML) ay itinuturing na mahaba.';
$string['configmanydiscussions'] = 'Maksimum na bilang ng usapan na ipapakita sa isang talakayan bawat pahina';
$string['configmaxbytes'] = 'Default na maksimum na laki para sa lahat ng kalakip sa talakayan sa site (alinsunod sa limitasyon sa kurso at iba pang lokal na kaayusan)';
$string['configoldpostdays'] = 'Bilang ng araw na lumipas para ituring na nabasa na ang alinmang post';
$string['configreplytouser'] = 'Kapag ang post sa talakayan ay ipinahatid balita, dapat ba itong maglaman ng email address ng email upang makatugon ang tatanggap ng personal sa halip na sa pamamagitan ng talakayan?  Kahit itakda na \'Oo\', maaari pa ring ilihim ng user ang email address nila sa pamamagitan ng kanilang pagkakakilanlan.';
$string['configshortpost'] = 'Anumang post na kulang sa haba na ito (dikasama ang HTML) ay itinuturing na maigsi.';
$string['configtrackreadposts'] = 'Itakda sa \'Oo\' kung nais mong i-track and nabasa/dinabasa para sa bawat user';
$string['configusermarksread'] = 'Kung \'oo\', kailang markahan ng user ang post ng \'nabasa\' nang mano-mano.  Kung \'hindi\', kapag ang post ay tiningnan ito ay mamarkahan na ng \'nabasa\'.';
$string['couldnotadd'] = 'Hindi maidagdag ang post mo dahil sa dimalamang error';
$string['couldnotdeleteratings'] = 'Paumanhin, hindi iyan maaaring mabura dahil nalagyan na ng rating ng mga tao.';
$string['couldnotdeletereplies'] = 'Paumanhin, hindi iyan maaaring mabura dahil tumugon na ang mga tao diyan.';
$string['couldnotupdate'] = 'Hindi mabago ang post mo dahil sa dimalamang dahilan';
$string['delete'] = 'Burahin';
$string['deleteddiscussion'] = 'Ang paksang pinag-uusapan ay binura na';
$string['deletedpost'] = 'Ang post ay binura na';
$string['deletedposts'] = 'Binura ang mga post na iyon';
$string['deletesure'] = 'Talaga bang nais mong burahin ang post na ito?';
$string['deletesureplural'] = 'Talaga bang nais mong burahin ang post na ito at lahat ng tugon dito? ($a post)';
$string['digestmailheader'] = 'Ito ang arawan mong digest ng bagong post mula sa $a->sitename na talakayan.  Para mabago ang mas-ibig mong kaayusan sa pantalakayang email, pumunta sa $a->userprefs.';
$string['digestmailprefs'] = 'ang pagkakakilanlan mo';
$string['digestmailsubject'] = '$a: digest ng talakayan';
$string['digestsentusers'] = 'Matagumpay na naihatid ang email digest sa $a user.';
$string['discussion'] = 'Usapan';
$string['discussionmoved'] = 'Ang usapang ito ay inilipat sa \'$a\'.';
$string['discussionname'] = 'Pangalan ng usapan';
$string['discussions'] = 'Mga Usapan';
$string['discussionsstartedby'] = 'Mga usapan na sinimulan ni $a';
$string['discussionsstartedbyrecent'] = 'Pinakabagong usapan na sinimulan ni $a';
$string['discussthistopic'] = 'Pag-usapan ang paksang ito';
$string['eachuserforum'] = 'Ang bawat tao ay nagpopost ng isang panimulang pag-uusapan';
$string['edit'] = 'Iedit';
$string['editedby'] = 'Inedit ni $a->name - $a->date';
$string['editing'] = 'Nageedit';
$string['emptymessage'] = 'May problema ang post mo.  Marahil ay blangko ito, o ang kalakip ay masyadong malaki.  Ang mga pagbabago mo ay HINDI nasave.';
$string['everyonecanchoose'] = 'Lahat ay maaaring sumali';
$string['everyoneissubscribed'] = 'Lahat ay kasali sa talakayang ito';
$string['existingsubscribers'] = 'Mga kasalukuyang kasali';
$string['forcesubscribe'] = 'Pilitin ang lahat na sumali';
$string['forcesubscribeq'] = 'Pipilitin ba ang lahat na sumali?';
$string['forum'] = 'Talakayan';
$string['forumintro'] = 'Panimula ng talakayan';
$string['forumname'] = 'Pangalan ng talakayan';
$string['forumposts'] = 'Mga post sa talakayan';
$string['forums'] = 'Mga talakayan';
$string['forumtype'] = 'Uri ng talakayan';
$string['generalforum'] = 'Karaniwang talakayan para sa pangkalahatang gamit';
$string['generalforums'] = 'Mga pangkalahatang talakayan';
$string['inforum'] = 'sa $a';
$string['intronews'] = 'Mga pangkalahatang balita at anunsiyo';
$string['introsocial'] = 'Bukas na talakayan para sa pakikipaghuntahan tungkol sa anumang bagay na nais mong pag-usapan.';
$string['introteacher'] = 'Talakayan para sa pangguro-lamang na mga tal at usapan';
$string['lastpost'] = 'Huling post';
$string['learningforums'] = 'Mga talakayan para sa pag-aaral';
$string['markalldread'] = 'Markahan ang lahat ng post sa usapang ito na \"nabasa na\".';
$string['markallread'] = 'Markahan ang lahat ng post sa talakayang ito na \"nabasa na\".';
$string['markread'] = 'Markahan na \"nabasa na\"';
$string['markreadbutton'] = 'Markahan na<br />nabasa na';
$string['markunread'] = 'Markahan na dinabasa';
$string['markunreadbutton'] = 'Markahan na<br />dinabasa';
$string['maxattachmentsize'] = 'Maksimum na laki ng kalakip';
$string['maxtimehaspassed'] = 'Paumanhin, nguni\'t ang taning na oras para maedit ang post na ito ($a) ay lumipas na!';
$string['message'] = 'Mensahe';
$string['missingsearchterms'] = 'Ang mga sumusunod na hinahanap na termino ay nasa HTML markup lamang ng mensaheng ito:';
$string['modeflatnewestfirst'] = 'Ipakita ang mga tugon nang flat, una ang pinakabago';
$string['modeflatoldestfirst'] = 'Ipakita ang mga tugon nang flat, una ang pinakaluma';
$string['modenested'] = 'Ipakita ang mga tugon sa anyong nakanest';
$string['modethreaded'] = 'Ipakita ang mga tugon sa anyong nakathread';
$string['modulename'] = 'Talakayan';
$string['modulenameplural'] = 'Mga Talakayan';
$string['more'] = 'marami pa';
$string['movethisdiscussionto'] = 'Ilipat ang usapang ito sa ... ';
$string['namenews'] = 'Balitaan';
$string['namesocial'] = 'Tambayan';
$string['nameteacher'] = 'Talakayan ng guro';
$string['newforumposts'] = 'Mga bagong post sa talakayan';
$string['nodiscussions'] = 'Wala pang pag-uusapang paksa sa talakayang ito';
$string['noguestpost'] = 'Paumanhin, pero hindi pinapahintulutang magpost ang mga bisita';
$string['noguestsubscribe'] = 'Paumanhin, nguni\'t ang mga bisita ay hindi pinapahintulutang sumali upang makatanggap ng post sa talakayan sa pamamagitan ng email.';
$string['noguesttracking'] = 'Paumanhin, nguni\'t hindi pinapahintulutan ang bisita na magtakda ng mga opsiyon sa pagsubaybay.';
$string['nomorepostscontaining'] = 'Wala nang matagpuang post na naglalaman ng \'$a\' ';
$string['nonews'] = 'Wala pang balita na ipinopost';
$string['noposts'] = 'Walang post';
$string['nopostscontaining'] = 'Walang natagpuang post na naglalaman ng \'$a\' ';
$string['nosubscribers'] = 'Wala pang kasali sa talakayang ito';
$string['notingroup'] = 'Paumanhin, nguni\'t kailangan ay kabilang ka sa isang pangkat para makita ang talakayang ito.';
$string['notrackforum'] = 'Huwag subaybayan ang mga dipanabasang mensahe';
$string['nownotsubscribed'] = 'Si $a->name ay HINDI makakatanggap ng kopya ng \'$a->forum\' sa pamamagitan ng email.';
$string['nownottracking'] = 'Si $a->name ay hindi na sinusubaybayan ang \'$a->forum\'.';
$string['nowsubscribed'] = 'Si $a->name ay makakatanggap ng kopya ng \'$a->forum\' sa pamamagitan ng email.';
$string['nowtracking'] = 'Sinusubaybayan na ni $a->name ang \'$a->forum\'.';
$string['numposts'] = '$a post';
$string['olderdiscussions'] = 'Mas lumang usapan';
$string['oldertopics'] = 'Mas lumang paksa';
$string['openmode0'] = 'Walang panimulang pag-uusapan, walang tugon';
$string['openmode1'] = 'Walang panimulang pag-uusapan, nguni\'t pinapahintulutan ang pagtugon';
$string['openmode2'] = 'Pinapahintulutan ang mga panimulang pag-uusapan at pagtugon';
$string['parent'] = 'Ipakita ang pinagsimulan';
$string['parentofthispost'] = 'Pinagsimulan ng post na ito';
$string['postadded'] = 'Matagumpay na naidagdag ang post mo.<p>May $a ka para maedit ito kung gusto mong baguhin.</p>';
$string['postincontext'] = 'Tingnan ang post na ito nang nasa konteksto';
$string['postmailinfo'] = 'Ito ay kopya ng mensaheng ipinost sa $a na website.

Upang maidagdag ang tugon mo sa pamamagitan ng website, iklik ang link na ito:';
$string['postrating1'] = 'Karamihan ay Hiwalay na Pag-alam';
$string['postrating2'] = 'Hiwalay at Konektado';
$string['postrating3'] = 'Karamihan ay Konektadong Pag-alam';
$string['posts'] = 'Mga Post';
$string['posttoforum'] = 'Magpost sa talakayan';
$string['postupdated'] = 'Nabago na ang post mo';
$string['potentialsubscribers'] = 'Mga posibleng kasali';
$string['processingdigest'] = 'Pinoproseso ang email digest para sa user na $a';
$string['processingpost'] = 'Pinoproseso ang post na $a';
$string['prune'] = 'Hatiin';
$string['prunedpost'] = 'May bagong usapan na nalikha mula sa post na iyan';
$string['pruneheading'] = 'Hatiin ang usapan at ilipat ang post na ito sa bagong usapan';
$string['rate'] = 'Rate';
$string['rating'] = 'Rating';
$string['ratingeveryone'] = 'Lahat ay maaaring magbigay ng rate sa mga post';
$string['ratingno'] = 'Walang rating';
$string['ratingonlyteachers'] = 'Tanging ang $a ang makapagbibigay ng rate sa mga post';
$string['ratingpublic'] = 'Ang $a ay maaaring makita ang rating ng lahat';
$string['ratingpublicnot'] = 'Ang $a ay maaari lamang makita ang sarili nilang rating';
$string['ratings'] = 'Mga Rating';
$string['ratingssaved'] = 'Nasave na ang mga rating';
$string['ratingsuse'] = 'Gumamit ng rating';
$string['ratingtime'] = 'Ibigay lamang ang rating sa mga post na may petsa na nasa agwat na ito:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Basahin ang nalalabing bahagi ng paksang ito';
$string['replies'] = 'Mga tugon';
$string['repliesmany'] = '$a tugon sa kasalukuyan';
$string['repliesone'] = '$a tugon sa kasalukuyan';
$string['reply'] = 'Tumugon';
$string['replyforum'] = 'Tumugon sa talakayan';
$string['rsssubscriberssdiscussions'] = 'Ipakita ang RSS feed para sa  \'$a\' usapan';
$string['rsssubscriberssposts'] = 'Ipakita ang RSS feed para sa \'$a\' post';
$string['search'] = 'Hanapin';
$string['searchdatefrom'] = 'Dapat ay mas bago ang mga post kaysa dito';
$string['searchdateto'] = 'Dapat ay mas luma ang mga post kaysa dito';
$string['searchforumintro'] = 'Pakipasok ang mga terminong hahanapin sa isa o mahigit pa sa mga sumusunod an field:';
$string['searchforums'] = 'Hanapin sa mga talakayan';
$string['searchfullwords'] = 'Dapat lumitaw ang mga salitang ito na buong salita';
$string['searchnotwords'] = 'HINDI dapat isama ang mga salitang ito';
$string['searcholderposts'] = 'Hanapin sa mga lumang post...';
$string['searchphrase'] = 'Kailangang lumitaw ang eksaktong kataga na ito sa post';
$string['searchresults'] = 'Resulta ng paghahanap';
$string['searchsubject'] = 'Dapat ay nasa paksa ang mga salitang ito';
$string['searchuser'] = 'Dapat tumugma ang pangalan sa awtor';
$string['searchuserid'] = 'Ang Moodle ID ng awtor';
$string['searchwhichforums'] = 'Piliin kung aling talakayan ang paghahanapan';
$string['searchwords'] = 'Maaaring lumitaw ang mga salitang ito saanman sa post';
$string['seeallposts'] = 'Tingnan ang lahat ng post na ginawa ng user na ito';
$string['sendinratings'] = 'Ipadala ang pinakabago kong rating';
$string['showsubscribers'] = 'Ipakita/editin ang mga kasalukuyang kasali';
$string['singleforum'] = 'Isang payak na usapan';
$string['startedby'] = 'Sinimulan ni';
$string['subject'] = 'Paksa';
$string['subscribe'] = 'Sumali sa talakayang ito';
$string['subscribeall'] = 'Isali ang lahat sa talakayang ito';
$string['subscribed'] = 'Kasali na';
$string['subscribenone'] = 'Tanggalin ang lahat sa talakayang ito';
$string['subscribers'] = 'Mga kasali';
$string['subscribersto'] = 'Mga kasali sa \'$a\'';
$string['subscribestart'] = 'Padalhan mo ako ng email na kopya ng mga post sa talakayang ito';
$string['subscribestop'] = 'Huwag mo akong padalhan ng email na kopya ng mga post sa talakayang ito';
$string['subscription'] = 'Sinalihan';
$string['subscriptions'] = 'Mga sinalihan';
$string['trackforum'] = 'Subaybayan ang mga dipanabasang mensahe';
$string['tracking'] = 'Subaybayan';
$string['trackingoff'] = 'Patay';
$string['trackingon'] = 'Buhay';
$string['trackingoptional'] = 'Opsiyonal';
$string['trackingtype'] = 'Babasahin ba ang pagsubaybay sa talakayang ito?';
$string['unread'] = 'Dinabasa';
$string['unreadposts'] = 'Mga dinabasang post';
$string['unreadpostsnumber'] = '$a dinabasang post';
$string['unreadpostsone'] = '1 dinabasang post';
$string['unsubscribe'] = 'Tanggalin sa talakayang ito';
$string['unsubscribed'] = 'Tinanggal';
$string['unsubscribeshort'] = 'Tanggalin';
$string['yesforever'] = 'Oo, magpakailanman';
$string['yesinitially'] = 'Oo, sa simula';
$string['youratedthis'] = 'Binigyan mo ng rate ito';
$string['yournewtopic'] = 'Ang bago mong paksang pinag-uusapan';
$string['yourreply'] = 'Ang iyong tugon';

?>
